@@ -1,5 +1,5 @@
 package Facebook::Graph::Picture;
-$Facebook::Graph::Picture::VERSION = '1.0900';
+$Facebook::Graph::Picture::VERSION = '1.1000';
 use Moo;
 with 'Facebook::Graph::Role::Uri';
 
@@ -38,7 +38,7 @@ sub uri_as_string {
         $query{type} = $self->type;
     }
     my $uri = $self->uri;
-    $uri->path($self->object_name . '/picture');
+    $uri->path($self->generate_versioned_path($self->object_name . '/picture'));
     $uri->query_form(%query);
     return $uri->as_string;
 }
@@ -52,7 +52,7 @@ Facebook::Graph::Picture - Get the URI for the picture of any object.
 
 =head1 VERSION
 
-version 1.0900
+version 1.1000
 
 =head1 SYNOPSIS
 
@@ -69,6 +69,23 @@ This module allows you to generate the URL needed to fetch a picture for any obj
 
 =head1 METHODS
 
+=head2 new ( [ params ] )
+
+=over
+
+=item params
+
+A hash or hashref of parameters to pass to the constructor.
+
+=over
+
+=item object_name
+
+An profile id like C<sarahbownds> or an object id like C<16665510298> for the Perl page.
+
+=item type
+
+Type of picture to return. Valid types are small, square, large
 
 =head2 get_large ( id )
 
