@@ -1,5 +1,5 @@
 package Facebook::Graph::Publish;
-$Facebook::Graph::Publish::VERSION = '1.0900';
+$Facebook::Graph::Publish::VERSION = '1.1000';
 use Moo;
 use Facebook::Graph::Request;
 with 'Facebook::Graph::Role::Uri';
@@ -40,7 +40,7 @@ sub get_post_params {
 sub publish {
     my ($self) = @_;
     my $uri = $self->uri;
-    $uri->path($self->object_name.$self->object_path);
+    $uri->path($self->generate_versioned_path($self->object_name.$self->object_path));
     return Facebook::Graph::Request->new->post($uri, $self->get_post_params)->recv;
 }
 
@@ -52,7 +52,7 @@ Facebook::Graph::Publish - A base class for publishing various things to faceboo
 
 =head1 VERSION
 
-version 1.0900
+version 1.1000
 
 =head1 DESCRIPTION
 
