@@ -1,5 +1,5 @@
 package Facebook::Graph::Query;
-$Facebook::Graph::Query::VERSION = '1.0900';
+$Facebook::Graph::Query::VERSION = '1.1000';
 use Moo;
 use Facebook::Graph::Request;
 with 'Facebook::Graph::Role::Uri';
@@ -186,7 +186,7 @@ sub uri_as_string {
         $query{ids} = join(',', @{$self->ids});
     }
     my $uri = $self->uri;
-    $uri->path($self->object_name);
+    $uri->path($self->generate_versioned_path($self->object_name));
     $uri->query_form(%query);
     return $uri->as_string;
 }
@@ -204,7 +204,7 @@ Facebook::Graph::Query - Simple and fast searching and fetching of Facebook data
 
 =head1 VERSION
 
-version 1.0900
+version 1.1000
 
 =head1 SYNOPSIS
 
