@@ -1,10 +1,20 @@
 package Facebook::Graph::Role::Uri;
-$Facebook::Graph::Role::Uri::VERSION = '1.0900';
+$Facebook::Graph::Role::Uri::VERSION = '1.1000';
 use Moo::Role;
 use URI;
 
 sub uri {
-    return URI->new('https://graph.facebook.com/v2.1')
+    return URI->new('https://graph.facebook.com')
+}
+
+has api_version => (
+    is  => 'rw',
+    default => 'v2.2',
+);
+
+sub generate_versioned_path {
+    my ($self, $path) = @_;
+    return join('/', $self->api_version, $path);
 }
 
 
@@ -16,7 +26,7 @@ Facebook::Graph::Role::Uri - The base URI for the Facebook Graph API.
 
 =head1 VERSION
 
-version 1.0900
+version 1.1000
 
 =head1 DESCRIPTION
 
